@@ -43,6 +43,12 @@ from .spec_maker_base import (
     OBJ_KEY,
     RENDERING_KEY,
     NAME_KEY,
+)
+from .elements import (
+    ElementTreeMaker,
+    ELEMENT_KEY,
+    FrontComponentBase,
+    FrontContainerBase,
+    FrontElementBase,
     DEFAULT_INPUT_KEY,
 )
-from .elements import ElementTreeMaker, ELEMENT_KEY
